@@ -618,32 +618,6 @@ CREATE TABLE IF NOT EXISTS backup_queue (
     INDEX idx_user (user)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;
 
--- Add permissions for backup management
-INSERT INTO permissions (name, description) VALUES
-    ('backup_manage_global', 'Manage global backup targets'),
-    ('backup_view_all', 'View all user backups'),
-    ('backup_download_all', 'Download all user backups'),
-    ('backup_delete_all', 'Delete all user backups'),
-    ('backup_manage_own', 'Manage own backup targets'),
-    ('backup_create', 'Create backups'),
-    ('backup_download_own', 'Download own backups'),
-    ('backup_delete_own', 'Delete own backups')
-ON DUPLICATE KEY UPDATE description = VALUES(description);
-
--- Grant backup permissions to root
-INSERT INTO user_permissions (username, permission_id)
-SELECT 'root', id FROM permissions WHERE name IN (
-    'backup_manage_global',
-    'backup_view_all',
-    'backup_download_all',
-    'backup_delete_all',
-    'backup_manage_own',
-    'backup_create',
-    'backup_download_own',
-    'backup_delete_own'
-)
-ON DUPLICATE KEY UPDATE username = VALUES(username);
-
 -- ================================================
 -- WORDPRESS MANAGEMENT TABLES
 -- ================================================
