@@ -35,6 +35,7 @@ $allowed_pages = [
     'user-resources' => 'User Resources',
     'domains' => 'Domains',
     'sites' => 'Sites',
+    'terminal' => 'Terminal',
     'server-settings' => 'Server Settings',
 ];
 
@@ -146,6 +147,9 @@ if (!array_key_exists($page, $allowed_pages)) {
                     <a href="index.php?page=sites" class="list-group-item list-group-item-action py-3 <?php echo $page === 'sites' ? 'active' : ''; ?>">
                         <i class="fa fa-server me-3"></i>Sites
                     </a>
+                    <a href="index.php?page=terminal" class="list-group-item list-group-item-action py-3 <?php echo $page === 'terminal' ? 'active' : ''; ?>">
+                        <i class="fa fa-terminal me-3"></i>Terminal
+                    </a>
                     <a href="index.php?page=wordpress" class="list-group-item list-group-item-action py-3 <?php echo $page === 'wordpress' ? 'active' : ''; ?>">
                         <i class="fa fa-wordpress me-3"></i>WordPress Management
                     </a>
